@@ -3,13 +3,13 @@ from typing import Any, Dict, List, cast
 from pygitguardian.client import VERSIONS
 from pygitguardian.models import Match, PolicyBreak
 
-from ggshield.filter import censor_content, leak_dictionary_by_ignore_sha
+from ggshield.core.filter import censor_content, leak_dictionary_by_ignore_sha
+from ggshield.core.text_utils import Line
+from ggshield.core.utils import Filemode, find_match_indices, get_lines_from_content
 from ggshield.output.json.schemas import ExtendedMatch, JSONScanCollectionSchema
 from ggshield.output.output_handler import OutputHandler
 from ggshield.scan import Result
-from ggshield.scan.scannable import ScanCollection
-from ggshield.text_utils import Line
-from ggshield.utils import Filemode, find_match_indices, get_lines_from_content
+from ggshield.scan.scannable import Error, ScanCollection
 
 
 class JSONOutputHandler(OutputHandler):
@@ -31,16 +31,20 @@ class JSONOutputHandler(OutputHandler):
         if scan.extra_info:
             scan_dict["extra_info"] = scan.extra_info
 
-        if top and scan.results:
+        if top and scan.has_results:
             scan_dict["secrets_engine_version"] = VERSIONS.secrets_engine_version
 
         if scan.results:
-            for result in scan.results:
+            for result in scan.results.results:
                 result_dict = self.process_result(result)
                 scan_dict.setdefault("results", []).append(result_dict)
                 scan_dict["total_incidents"] += result_dict["total_incidents"]
                 scan_dict["total_occurrences"] += result_dict["total_occurrences"]
 
+            for error in scan.results.errors:
+                error_dict = self.process_error(error)
+                scan_dict.setdefault("errors", []).append(error_dict)
+
         if scan.scans:
             for inner_scan in scan.scans_with_results:
                 inner_scan_dict = self.create_scan_dict(inner_scan, top=False)
@@ -81,6 +85,20 @@ class JSONOutputHandler(OutputHandler):
 
         return result_dict
 
+    @staticmethod
+    def process_error(error: Error) -> Dict[str, Any]:
+        error_dict: Dict[str, Any] = {
+            "files": [
+                {
+                    "filename": filename,
+                    "mode": filemode.name,
+                }
+                for filename, filemode in error.files
+            ],
+            "description": error.description,
+        }
+        return error_dict
+
     def flattened_policy_break(
         self,
         ignore_sha: str,
