@@ -1,14 +1,14 @@
 from io import StringIO
-from typing import ClassVar, List
+from typing import ClassVar, List, cast
 
 import click
 from pygitguardian.models import Match
 
-from ggshield.filter import censor_content, leak_dictionary_by_ignore_sha
+from ggshield.core.filter import censor_content, leak_dictionary_by_ignore_sha
+from ggshield.core.text_utils import Line
+from ggshield.core.utils import Filemode, find_match_indices, get_lines_from_content
 from ggshield.output.output_handler import OutputHandler
-from ggshield.scan import Result, ScanCollection
-from ggshield.text_utils import LINE_DISPLAY, Line
-from ggshield.utils import Filemode, find_match_indices, get_lines_from_content
+from ggshield.scan import Result, Results, ScanCollection
 
 from .message import (
     file_info,
@@ -18,20 +18,7 @@ from .message import (
     policy_break_header,
     secrets_engine_version,
 )
-
-
-def get_padding(lines: List[Line]) -> int:
-    """Return the number of digit of the maximum line number."""
-    # value can be None
-    return max(len(str(lines[-1].pre_index or 0)), len(str(lines[-1].post_index or 0)))
-
-
-def get_offset(padding: int, is_patch: bool = False) -> int:
-    """Return the offset due to the line display."""
-    if is_patch:
-        return len(LINE_DISPLAY["patch"].format("0" * padding, "0" * padding))
-
-    return len(LINE_DISPLAY["file"].format("0" * padding))
+from .utils import get_offset, get_padding
 
 
 class TextOutputHandler(OutputHandler):
@@ -39,23 +26,22 @@ class TextOutputHandler(OutputHandler):
 
     def _process_scan_impl(self, scan: ScanCollection, top: bool = True) -> str:
         scan_buf = StringIO()
-        if scan.optional_header and (scan.results or self.verbose):
+        if scan.optional_header and (scan.has_results or self.verbose):
             scan_buf.write(scan.optional_header)
 
-        if top and (scan.results or self.verbose):
+        if top and (scan.has_results or self.verbose):
             scan_buf.write(secrets_engine_version())
 
-        if scan.results:
-            for result in scan.results:
+        if scan.has_results:
+            for result in cast(Results, scan.results).results:
                 scan_buf.write(self.process_result(result))
         else:
-            if self.verbose:
-                has_results = False
-                if scan.scans:
-                    has_results = any(x.results for x in scan.scans)
+            has_results = False
+            if scan.scans:
+                has_results = any(x.has_results for x in scan.scans)
 
-                if not has_results:
-                    scan_buf.write(no_leak_message())
+            if top and not has_results:
+                scan_buf.write(no_leak_message())
 
         if scan.scans:
             for sub_scan in scan.scans:
