@@ -1,13 +1,18 @@
+import logging
 from ast import literal_eval
 from typing import Dict, List
 
 import click
 from pygitguardian.models import Detail
 
-from ggshield.text_utils import STYLE, display_error, format_text, pluralize
+from ggshield.core.text_utils import STYLE, display_error, format_text, pluralize
 
 
-def handle_scan_error(detail: Detail, chunk: List[Dict[str, str]]) -> None:
+logger = logging.getLogger(__name__)
+
+
+def handle_scan_chunk_error(detail: Detail, chunk: List[Dict[str, str]]) -> None:
+    logger.error("status_code=%d detail=%s", detail.status_code, detail.detail)
     if detail.status_code == 401:
         raise click.UsageError(detail.detail)
 
@@ -43,3 +48,11 @@ def handle_scan_error(detail: Detail, chunk: List[Dict[str, str]]) -> None:
         )
 
         display_error(str(detail))
+
+
+def handle_scan_error(detail: Detail) -> None:
+    logger.error("status_code=%d detail=%s", detail.status_code, detail.detail)
+    if detail.status_code == 401:
+        raise click.UsageError(detail.detail)
+    display_error("\nError scanning.")
+    display_error(str(detail))
